@@ -27,28 +27,25 @@
 #ifndef WP6GRAPHICSCACHEDFILEDATAPACKET_H
 #define WP6GRAPHICSCACHEDFILEDATAPACKET_H
 #include "WP6PrefixDataPacket.h"
-#include "WP6FileStructure.h"
-#include "WPXBinaryData.h"
 #include "WP6Listener.h"
 
 class WP6GraphicsCachedFileDataPacket : public WP6PrefixDataPacket
 {
 public:
-	WP6GraphicsCachedFileDataPacket(WPXInputStream *input, WPXEncryption *encryption, int id, uint32_t dataOffset, uint32_t dataSize);
-	~WP6GraphicsCachedFileDataPacket();
-	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
-	void parse(WP6Listener * /* listener */) const {}
-	const WPXBinaryData *getBinaryObject() const
+	WP6GraphicsCachedFileDataPacket(librevenge::RVNGInputStream *input, WPXEncryption *encryption, int id, unsigned dataOffset, unsigned dataSize);
+	~WP6GraphicsCachedFileDataPacket() override;
+	void _readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption) override;
+	void parse(WP6Listener * /* listener */) const override {}
+	const librevenge::RVNGBinaryData *getBinaryObject() const
 	{
-		return m_object;
+		return m_object.get();
 	}
 
 private:
 	WP6GraphicsCachedFileDataPacket(const WP6GraphicsCachedFileDataPacket &);
 	WP6GraphicsCachedFileDataPacket &operator=(const WP6GraphicsCachedFileDataPacket &);
 	int m_id;
-	WPXBinaryData *m_object;
-	uint8_t *m_data;
+	std::unique_ptr<librevenge::RVNGBinaryData> m_object;
 
 };
 #endif /* WP6GRAPHICSCACHEDFILEDATAPACKET_H */
