@@ -30,22 +30,22 @@
 #include <map>
 #include <vector>
 
-typedef std::map<int, WP6PrefixDataPacket *> DPH;
-typedef std::multimap<int, WP6PrefixDataPacket *> MPDP;
+typedef std::map<int, std::shared_ptr<WP6PrefixDataPacket>> DPH;
+typedef std::multimap<int, std::shared_ptr<WP6PrefixDataPacket>> MPDP;
 typedef MPDP::const_iterator MPDP_CIter;
 typedef MPDP::iterator MPDP_Iter;
 
 class WP6PrefixData
 {
 public:
-	WP6PrefixData(WPXInputStream *input, WPXEncryption *encryption, const int numPrefixIndices);
+	WP6PrefixData(librevenge::RVNGInputStream *input, WPXEncryption *encryption, const int numPrefixIndices);
 	virtual ~WP6PrefixData();
 	const WP6PrefixDataPacket *getPrefixDataPacket(const int prefixID) const;
 	std::pair< MPDP_CIter, MPDP_CIter > getPrefixDataPacketsOfType(const int type) const;
 
-	uint16_t getDefaultInitialFontPID() const
+	unsigned short getDefaultInitialFontPID() const
 	{
-		return (uint16_t)m_defaultInitialFontPID;
+		return (unsigned short)m_defaultInitialFontPID;
 	}
 
 private:
