@@ -1,20 +1,20 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwpd
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwpd.sourceforge.net
  */
@@ -27,43 +27,40 @@
 #define WPXCONTENTLISTENER_H
 
 #include "WPXTable.h"
-#include "WPXPropertyListVector.h"
-#include "WPXPropertyList.h"
+#include "WPXTableList.h"
 #include "libwpd_internal.h"
 #include "WPXSubDocument.h"
 #include "WPXPageSpan.h"
-#include "WPXDocumentInterface.h"
 #include "WPXListener.h"
+#include <memory>
 #include <vector>
 #include <list>
 #include <set>
 
-typedef struct _WPXTableDefinition WPXTableDefinition;
-struct _WPXTableDefinition
+struct WPXTableDefinition
 {
-	_WPXTableDefinition() : m_positionBits(0), m_leftOffset(0.0), m_columns(), m_columnsProperties() {}
-	uint8_t m_positionBits;
+	WPXTableDefinition() : m_positionBits(0), m_leftOffset(0.0), m_columns(), m_columnsProperties() {}
+	unsigned char m_positionBits;
 	double m_leftOffset;
 	std::vector < WPXColumnDefinition > m_columns;
 	std::vector < WPXColumnProperties > m_columnsProperties;
 };
 
-typedef struct _WPXContentParsingState WPXContentParsingState;
-struct _WPXContentParsingState
+struct WPXContentParsingState
 {
-	_WPXContentParsingState();
-	~_WPXContentParsingState();
+	WPXContentParsingState();
+	~WPXContentParsingState();
 
-	uint32_t m_textAttributeBits;
+	unsigned m_textAttributeBits;
 	double m_fontSize;
-	WPXString *m_fontName;
-	RGBSColor *m_fontColor;
-	RGBSColor *m_highlightColor;
+	std::unique_ptr<librevenge::RVNGString> m_fontName;
+	std::unique_ptr<RGBSColor> m_fontColor;
+	std::unique_ptr<RGBSColor> m_highlightColor;
 
 	bool m_isParagraphColumnBreak;
 	bool m_isParagraphPageBreak;
-	uint8_t m_paragraphJustification;
-	uint8_t m_tempParagraphJustification; // TODO: remove this one after the tabs are properly implemented
+	unsigned char m_paragraphJustification;
+	unsigned char m_tempParagraphJustification; // TODO: remove this one after the tabs are properly implemented
 	double m_paragraphLineSpacing;
 
 	bool m_isDocumentStarted;
@@ -90,15 +87,15 @@ struct _WPXContentParsingState
 	bool m_wasHeaderRow;
 	bool m_isCellWithoutParagraph;
 	bool m_isRowWithoutCell;
-	uint32_t m_cellAttributeBits;
-	uint8_t m_paragraphJustificationBeforeTable;
+	unsigned m_cellAttributeBits;
+	unsigned char m_paragraphJustificationBeforeTable;
 
 	unsigned m_currentPage;
-	int m_numPagesRemainingInSpan;
-	int m_currentPageNumber;
+	unsigned m_numPagesRemainingInSpan;
+	unsigned m_currentPageNumber;
 
 	bool m_sectionAttributesChanged;
-	int m_numColumns;
+	unsigned m_numColumns;
 	std::vector < WPXColumnDefinition > m_textColumns;
 	bool m_isTextColumnWithoutParagraph;
 
@@ -130,9 +127,9 @@ struct _WPXContentParsingState
 	double m_textIndentByParagraphIndentChange; // part of the indent due to the PARAGRAPH indent (WP6???)
 	double m_textIndentByTabs; // part of the indent due to the "Back Tab" or "Left Tab"
 
-	uint8_t m_currentListLevel;
+	unsigned char m_currentListLevel;
 
-	uint16_t m_alignmentCharacter;
+	unsigned m_alignmentCharacter;
 	std::vector<WPXTabStop> m_tabStops;
 	bool m_isTabPositionRelative;
 
@@ -143,30 +140,30 @@ struct _WPXContentParsingState
 	WPXSubDocumentType m_subDocumentType;
 
 private:
-	_WPXContentParsingState(const _WPXContentParsingState &);
-	_WPXContentParsingState &operator=(const _WPXContentParsingState &);
+	WPXContentParsingState(const WPXContentParsingState &);
+	WPXContentParsingState &operator=(const WPXContentParsingState &);
 };
 
 class WPXContentListener : public WPXListener
 {
 protected:
-	WPXContentListener(std::list<WPXPageSpan> &pageList, WPXDocumentInterface *documentInterface);
-	virtual ~WPXContentListener();
+	WPXContentListener(std::list<WPXPageSpan> &pageList, librevenge::RVNGTextInterface *documentInterface);
+	~WPXContentListener() override;
 
 	void startDocument();
 	void startSubDocument();
 	void endDocument();
 	void endSubDocument();
-	void handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice);
-	void insertBreak(const uint8_t breakType);
+	void handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, unsigned nextTableIndice);
+	void insertBreak(const unsigned char breakType);
 	void lineSpacingChange(const double lineSpacing);
-	void justificationChange(const uint8_t justification);
+	void justificationChange(const unsigned char justification);
 
-	WPXContentParsingState *m_ps; // parse state
-	WPXDocumentInterface *m_documentInterface;
-	WPXPropertyList m_metaData;
+	std::unique_ptr<WPXContentParsingState> m_ps; // parse state
+	librevenge::RVNGTextInterface *m_documentInterface;
+	librevenge::RVNGPropertyList m_metaData;
 
-	virtual void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, int nextTableIndice) = 0;
+	virtual void _handleSubDocument(const WPXSubDocument *subDocument, WPXSubDocumentType subDocumentType, WPXTableList tableList, unsigned nextTableIndice) = 0;
 	virtual void _flushText() = 0;
 	virtual void _changeList() = 0;
 
@@ -176,9 +173,9 @@ protected:
 	void _openPageSpan();
 	void _closePageSpan();
 
-	void _appendParagraphProperties(WPXPropertyList &propList, const bool isListElement=false);
-	void _getTabStops(WPXPropertyListVector &tabStops);
-	void _appendJustification(WPXPropertyList &propList, int justification);
+	void _appendParagraphProperties(librevenge::RVNGPropertyList &propList, const bool isListElement=false);
+	void _getTabStops(librevenge::RVNGPropertyListVector &tabStops);
+	void _appendJustification(librevenge::RVNGPropertyList &propList, int justification);
 	void _resetParagraphState(const bool isListElement=false);
 	virtual void _openParagraph();
 	void _closeParagraph();
@@ -193,7 +190,7 @@ protected:
 	void _closeTable();
 	void _openTableRow(const double height, const bool isMinimumHeight, const bool isHeaderRow);
 	void _closeTableRow();
-	void _openTableCell(const uint8_t colSpan, const uint8_t rowSpan, const uint8_t borderBits,
+	void _openTableCell(const unsigned char colSpan, const unsigned char rowSpan, const unsigned char borderBits,
 	                    const RGBSColor *cellFgColor, const RGBSColor *cellBgColor,
 	                    const RGBSColor *cellBorderColor,
 	                    const WPXVerticalAlignment cellVerticalAlignment);
@@ -204,21 +201,21 @@ protected:
 	double _getNextTabStop() const;
 	double _getPreviousTabStop() const;
 
-	void _insertText(const WPXString &textBuffer);
+	void _insertText(const librevenge::RVNGString &textBuffer);
 
-	void _insertBreakIfNecessary(WPXPropertyList &propList);
+	void _insertBreakIfNecessary(librevenge::RVNGPropertyList &propList);
 
-	void _insertPageNumberParagraph(WPXPageNumberPosition position, WPXNumberingType type, WPXString fontName, double fontSize);
+	void _insertPageNumberParagraph(WPXPageNumberPosition position, WPXNumberingType type, librevenge::RVNGString fontName, double fontSize);
 
-	uint32_t _mapNonUnicodeCharacter(uint32_t character);
+	unsigned _mapNonUnicodeCharacter(unsigned character);
 
 private:
 	WPXContentListener(const WPXContentListener &);
 	WPXContentListener &operator=(const WPXContentListener &);
-	WPXString _colorToString(const RGBSColor *color);
-	WPXString _mergeColorsToString(const RGBSColor *fgColor, const RGBSColor *bgColor);
-	uint32_t _mapSymbolFontCharacter(uint32_t character);
-	uint32_t _mapDingbatsFontCharacter(uint32_t character);
+	librevenge::RVNGString _colorToString(const RGBSColor *color);
+	librevenge::RVNGString _mergeColorsToString(const RGBSColor *fgColor, const RGBSColor *bgColor);
+	unsigned _mapSymbolFontCharacter(unsigned character);
+	unsigned _mapDingbatsFontCharacter(unsigned character);
 };
 
 #endif /* WPXCONTENTLISTENER_H */
